import Vue from 'vue'; // 引入 Vue.js
import VueRouter from 'vue-router'; // 引入 Vue Router
import GlobalLayout from '@/layouts/GlobalLayout'; // 引入全局布局组件

Vue.use(VueRouter); // 使用 Vue Router

const RouteView = {
  name: 'RouteView',
  render: h => h('router-view'), // 渲染路由视图组件
};
// 定义路由配置数组
export const routes = [{
  path: '/', // 根路由
  name: 'Home',
  meta: { title: '主页' },
  redirect: '/race/list', // 重定向至赛事列表页面
  component: GlobalLayout, // 使用全局布局组件
  children: [{
    path: '/race', // 赛事管理路由
    name: 'Race',
    redirect: '/race/list', // 默认重定向至赛事列表页面
    component: RouteView, // 使用路由视图组件
    meta: { title: '赛事管理', icon: 'appstore' }, // 路由元信息
    children: [{
      path: '/race/list', // 赛事列表路由
      name: 'RaceList',
      component: () =>
        import('@/views/race/Race'), // 异步加载赛事列表组件
      meta: { title: '赛事列表', auth: 'race:query' }, // 路由元信息，指定需要的权限
    },
    {
      path: '/race/record', // 参赛记录路由
      name: 'Record',
      component: () =>
        import('@/views/race/Record'), // 异步加载参赛记录组件
      meta: { title: '参赛记录', auth: 'record:query' }, // 路由元信息，指定需要的权限
    },
    ],
  },
  {
    path: '/user', // 用户管理路由
    redirect: '/user/student', // 默认重定向至学生列表页面
    name: 'User',
    component: RouteView, // 使用路由视图组件
    meta: { title: '用户管理', icon: 'user', auth: 'user:query' }, // 路由元信息，指定需要的权限
    children: [{
      path: '/user/student', // 学生列表路由
      name: 'Student',
      component: () =>
        import('@/views/user/Student'), // 异步加载学生列表组件
      meta: { title: '学生列表' }, // 路由元信息
    },
    {
      path: '/user/teacher', // 教师列表路由
      name: 'Teacher',
      component: () =>
        import('@/views/user/Teacher'), // 异步加载教师列表组件
      meta: { title: '教师列表' }, // 路由元信息
    },
    ],
  },
  {
    path: '/role', // 权限管理路由
    redirect: '/role/list', // 默认重定向至角色列表页面
    name: 'Role',
    component: RouteView, // 使用路由视图组件
    meta: { title: '权限管理', icon: 'key' }, // 路由元信息
    children: [{
      path: '/role/list', // 角色列表路由
      name: 'RoleList',
      meta: { title: '角色列表', auth: 'role:query' }, // 路由元信息，指定需要的权限
      component: () =>
        import('@/views/role/RoleList'), // 异步加载角色列表组件
    },
    {
      path: '/role/permission', // 权限列表路由
      name: 'Permission',
      meta: { title: '权限列表', auth: 'permission:query' }, // 路由元信息，指定需要的权限
      component: () =>
        import('@/views/role/PermissionList'), // 异步加载权限列表组件
    },
    ],
  }, {
    path: '/community', // 权限管理路由
    redirect: '/community/list', // 默认重定向至角色列表页面
    name: 'Role',
    component: RouteView, // 使用路由视图组件
    meta: { title: '交流社区', icon: 'key' }, // 路由元信息
    children: [
      {
      path: '/community/list', // 角色列表路由
      name: 'Applications',
      meta: { title: '角色列表', auth: 'role:query' }, // 路由元信息，指定需要的权限
      component: () =>
        import('@/views/communtiy/Applications.vue'), // 异步加载角色列表组件
    },
      {
        path: '/community/Article', // 权限列表路由
        name: 'Article',
        meta: { title: '权限列表', auth: 'permission:query' }, // 路由元信息，指定需要的权限
        component: () =>
          import('@/views/communtiy/Article.vue'), // 异步加载权限列表组件
      },
      {
        path: '/community/Projects', // 权限列表路由
        name: 'Article',
        meta: { title: '权限列表', auth: 'permission:query' }, // 路由元信息，指定需要的权限
        component: () =>
          import('@/views/communtiy/Projects.vue'), // 异步加载权限列表组件
      }
    ],
  }, {
    path: '/account', // 权限管理路由
    // redirect: '/account/center', // 默认重定向至角色列表页面
    name: 'Role',
    component: RouteView, // 使用路由视图组件
    meta: { title: '个人中心', icon: 'key' }, // 路由元信息
    children: [
      {
      path: '/account/center', // 角色列表路由
      name: 'AccountCenter',
      meta: { title: '个人中心', auth: 'role:query' }, // 路由元信息，指定需要的权限
      component: () =>
        import('@/views/account/center/index.vue'), // 异步加载角色列表组件
    },{
      path: '/account/settings', // 角色列表路由
      name: 'AccountSettings',
			redirect: '/account/settings/basic', // 添加这行来重定向到默认的子路由
      meta: { title: '个人设置', auth: 'role:query' }, // 路由元信息，指定需要的权限
      component: () =>
        import('@/views/account/settings/Index.vue'), // 异步加载角色列表组件
				children: [
					// ...其他子路由
					{
						path: '/account/settings/basic', // 完整路径将是 /account/settings/security
						name: 'BasicSettings',
						component: () => import('@/views/account/settings/BasicSetting'), // 你的 SecuritySettings 组件
						meta: {
							keepAlive: false,
							hiddenHeaderContent: true,
							hidden: true, // 这将指示UI组件隐藏此路由
						}
					},{
						path: '/account/settings/security', // 完整路径将是 /account/settings/security
						name: 'SecuritySettings',
						component: () => import('@/views/account/settings/Security.vue'), // 你的 SecuritySettings 组件
						meta: {
							keepAlive: false,
							hiddenHeaderContent: true,
							hidden: true, // 这将指示UI组件隐藏此路由
						}
					},{
						path: '/account/settings/notification', // 完整路径将是 /account/settings/security
						name: 'NotificationSettings',
						component: () => import('@/views/account/settings/Notification.vue'), // 你的 SecuritySettings 组件
						meta: {
							keepAlive: false,
							hiddenHeaderContent: true,
							hidden: true, // 这将指示UI组件隐藏此路由
						}
					},
					// ...其他子路由
				]
    },
      
    ],
  },
  ],
},
{
  path: '/login', // 登录页面路由
  name: 'Login',
  meta: { title: '登陆' }, // 路由元信息
  component: () =>
    import('@/views/Login'), // 异步加载登录页面组件
},
{
  path: '/404', // 404 页面路由
  component: () =>
    import('@/components/common/404'), // 异步加载 404 组件
},
{
  path: '*', // 匹配任何不存在的路由
  redirect: '/404', // 重定向至 404 页面
},
];

const router = new VueRouter({
  mode: 'history', // 使用 HTML5 History 模式
  base: process.env.BASE_URL, // 应用的基础 URL
  routes, // 路由配置数组
});

/**
 * 根据权限过滤路由，生成 pro-layout 需要的 menu
 * @param {[]} routes 路由配置数组
 * @param {[]} permission 当前用户拥有的权限
 */
// export function filterRoutes(routes, permission) {
//   const set = new Set(permission); // 将权限数组转为 Set 集合，便于查找

//   function filter(routes) {
//     const arr = [];
//     for (const route of routes) {
//       // 获取当前路由的权限信息
//       const auth = route.meta ? route.meta.auth : undefined;
//       if (!auth || set.has(auth)) { // 如果路由无需权限或用户具有相应权限
//         arr.push(route); // 将路由添加到结果数组中
//         if (route.children) {
//           const children = filter(route.children); // 递归过滤子路由
//           route.children = children; // 更新子路由数组
//           if (!children.length) {
//             route.hidden = true; // 如果子路由数组为空，则隐藏菜单项
//           }
//         }
//       }
//     }
//     return arr; // 返回过滤后的路由数组
//   }

//   return filter(routes); // 返回过滤后的路由配置数组
// }

// export default router; // 导出 Vue Router 实例
// export function filterRoutes(routes, permission) {
//   const set = new Set(permission); // 将权限数组转为 Set 集合，便于查找

//   function filter(routes) {
//     const arr = [];
//     for (const route of routes) {
//       // 检查路由是否隐藏
//       if (route.meta && route.meta.hidden) {
//         continue; // 如果路由被隐藏，则跳过这个路由
//       }
      
//       const auth = route.meta ? route.meta.auth : undefined;
//       if (!auth || set.has(auth)) { // 如果路由无需权限或用户具有相应权限
//         if (route.children) {
//           const children = filter(route.children); // 递归过滤子路由
//           route.children = children; // 更新子路由数组
//           if (!children.length && route.children) {
//             route.hidden = true; // 如果子路由数组为空，则隐藏菜单项
//           }
//         }
//         arr.push(route); // 将路由添加到结果数组中
//       }
//     }
//     return arr; // 返回过滤后的路由数组
//   }

//   return filter(routes); // 返回过滤后的路由配置数组
// }
// export default router; // 导出 Vue Router 实例
export function filterRoutes(routes, permission) {
	const set = new Set(permission);
 
 function filter(routes, isParentVisible = true) {
	return routes.reduce((acc, route) => {
	// 如果路由被标记为隐藏，且其父路由不是强制显示的，则跳过
	if (route.meta && route.meta.hidden && !isParentVisible) return acc;
 
 let filteredRoute = { ... route };
	if (route.children) {
	filteredRoute.children = filter(route.children, route.meta && route.meta.alwaysShow);
	}
 
 // 特别检查是否当前路由是AccountSettings，如果是，即使所有子路由隐藏也显示
	if (filteredRoute.name === "AccountSettings" || !filteredRoute.meta || !filteredRoute.meta.hidden || set.has(filteredRoute.meta.auth)) {
	acc.push(filteredRoute);
	}
	return acc;
	}, []);
	}
 
 return filter(routes);
 }
export default router; // 导出 Vue Router 实例