import Vue from 'vue'; // 引入 Vue.js
import Cookie from 'js-cookie'; // 引入 Cookie 操作库
import Vuex, { createLogger } from 'vuex'; // 引入 Vuex 状态管理库及日志插件
import { getUserData } from '@/api'; // 引入获取用户数据的 API 方法

Vue.use(Vuex); // 使用 Vuex
const debug = process.env.NODE_ENV !== 'production'; // 判断是否为开发环境

// 创建 Vuex Store 实例
const store = new Vuex.Store({
    strict: debug, // 开启严格模式
    plugins: debug ? [createLogger()] : [], // 在开发环境下启用日志插件
    state: {
        user: {}, // 用户信息对象
    },
    getters: {
        permissions(state) {
            return state.user.permissions || []; // 获取用户权限列表
        },
    },
    actions: {
        // 初始化用户数据
        initUser({ commit }) {
            return getUserData().then(data => {
                commit('setUserData', data.data); // 提交用户数据至 mutations
                return data.data; // 返回用户数据
            });
        },
    },
    mutations: {
        // 登出，移除用户标识符
        logout() {
            Cookie.remove('uid'); // 移除 uid Cookie
        },
        // 设置用户数据
        setUserData(state, user) {
            state.user = user; // 更新用户信息
        },
    },
});

export default store; // 导出 Vuex Store

/**
 * 判断当前用户是否具有对应的权限
 * @param {string} permission 权限字符串，类似于 user:query
 * @returns {boolean} 返回布尔值，表示用户是否具有该权限
 */
Vue.prototype.$has = function(permission) {
    return store.getters.permissions.some(v => v === permission); // 判断用户权限列表中是否包含指定权限
};